@@ -1,10 +1,20 @@
 import numpy as np
 import pandas as pd
 import pickle
+import google.cloud.storage as storage
 from google.cloud import bigquery
 from sklearn.preprocessing import MultiLabelBinarizer, OneHotEncoder, LabelEncoder
 from sklearn.preprocessing import PolynomialFeatures
-from beam_utils.utils import upload_blob
+
+
+def upload_blob(bucket_name, source_file_name, destination_blob_name):
+    """Uploads a file to the bucket."""
+    storage_client = storage.Client()
+    bucket = storage_client.get_bucket(bucket_name)
+    blob = bucket.blob(destination_blob_name)
+    blob.upload_from_filename(source_file_name)
+
+    print('File {} uploaded to {}.'.format(source_file_name, destination_blob_name))
 
 
 def create_equipment_type_multilabel_binarizer():
